summaryrefslogtreecommitdiff
path: root/lib/ansible/plugins
diff options
context:
space:
mode:
authorMatt Martz <matt@sivel.net>2021-02-05 09:06:19 -0600
committerGitHub <noreply@github.com>2021-02-05 09:06:19 -0600
commitd3f3784b86789b7b55782b0af4fba6d6bb935f19 (patch)
treee934cfe3ad1e653fb2914e1db1cbc72d9198fcbb /lib/ansible/plugins
parent8d6136eab96dc2c0745996eb9bbb893e93015d2e (diff)
downloadansible-d3f3784b86789b7b55782b0af4fba6d6bb935f19.tar.gz
Don't treat host_pinned as lockstep (#73484)
* Don't treat host_pinned as lockstep. Fixes #73364 * Add intg tests
Diffstat (limited to 'lib/ansible/plugins')
-rw-r--r--lib/ansible/plugins/callback/default.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/ansible/plugins/callback/default.py b/lib/ansible/plugins/callback/default.py
index 7872974d4f..9087aacdf2 100644
--- a/lib/ansible/plugins/callback/default.py
+++ b/lib/ansible/plugins/callback/default.py
@@ -188,8 +188,8 @@ class CallbackModule(CallbackBase):
# Preserve task name, as all vars may not be available for templating
# when we need it later
- if self._play.strategy == 'free':
- # Explicitly set to None for strategy 'free' to account for any cached
+ if self._play.strategy in ('free', 'host_pinned'):
+ # Explicitly set to None for strategy free/host_pinned to account for any cached
# task title from a previous non-free play
self._last_task_name = None
else: